.. _settings:

=============
Site Settings
=============

Review Board sites can be configured through the Settings portion of the
:ref:`Administration UI <administration-ui>`. You'll generally need to make
some changes in here before others use the site.

The list of settings pages are available on the left-hand side panel of any
page in the :ref:`Administration UI <administration-ui>` under
:guilabel:`System Settings`.

They include:

.. toctree::
   :maxdepth: 1

   General <general-settings>
   Authentication <authentication-settings>
   Avatar Services <avatar-services-settings>
   E-Mail <email-settings>
   Diff Viewer <diffviewer-settings>
   Logging <logging-settings>
   SSH <ssh-settings>
   File Storage <file-storage-settings>


You can also get an overview of a few key settings near the bottom of the side
panel as well, under :guilabel:`System Information`.
